import { AxiosResponse } from 'axios'
import {
    ResultOutputCompanyDrawOutput,
    CompanyDrawInput,
    pageInputProjectPriceSetPageInput,
    ResultOutputPageOutputPriceGetPageOutput,
} from './data-contracts'
import { ContentType, HttpClient, RequestParams } from './http-client'

export class ProjectPriceApi<SecurityDataType = unknown> extends HttpClient<SecurityDataType>{
    /**
   * No description
   *
   * @tags role
   * @name Get
   * @summary 查询公司抽成信息
   * @request GET:/api/admin/project-price/get-company-draw
   * @secure
   */
    getCompanyDraw = (
        query?: {            
        },
        params: RequestParams = {}
    ) =>
        this.request<ResultOutputCompanyDrawOutput, any>({
            path: `/api/admin/project-price/get-company-draw`,
            method: 'GET',
            query: query,
            secure: true,
            format: 'json',
            ...params,
        })
    /**
   * No description
   *
   * @tags org
   * @name Update
   * @summary 修改公司抽成比例
   * @request Post:/api/admin/project-price/edit-company-draw
   * @secure
   */
    updateCompany = (data: CompanyDrawInput, params: RequestParams = {}) =>
        this.request<AxiosResponse, any>({
            path: `/api/admin/project-price/edit-company-draw`,
            method: 'Post',
            body: data,
            secure: true,
            type: ContentType.Json,
            ...params,
        })
    /**
   * No description
   *
   * @tags projectprice
   * @name GetPage
   * @summary 查询项目价格分页
   * @request POST:/api/admin/project-price/get-page
   * @secure
   */
    getPricePage = (data: pageInputProjectPriceSetPageInput, params: RequestParams = {}) =>
        this.request<ResultOutputPageOutputPriceGetPageOutput, any>({
            path: `/api/admin/project-price/get-page`,
            method: 'Post',
            body: data,
            secure: true,
            type: ContentType.Json,
            format: 'json',
            ...params,
        })
}